import React, { useEffect, useMemo, useState, useRef } from "react";
import Taro, { useDidShow, useRouter } from "@tarojs/taro";
import "./index.scss";
import { View, Text, Input, Image } from "@tarojs/components";
import ContainerLayout from "../../compents/container/index";
import Tab from "../../compents/tab/index";
import Layout from "../../layout/index";
import request from "../../util/request";
import getQueryValue from "../../util/getQueryValue";
import NoData from "@/compents/NoData";
import InifiniteList from "@/compents/InifiniteList";
import IsLogin from "../../layout/IsLogin";

const account = props => {
  const tabRef = useRef()
  const { id } = getQueryValue();
  const [list, setList] = useState([]);
  const [page, setPage] = useState({ total: 0, pageNum: 0 });
  const [listHeight, setListHeight] = useState('600')

  useDidShow(() => {
    console.log("useDidShow");
    getShopKepperList({ pageNum: 1, pageSize: 10 });
  });

  function getShopKepperList(params) {
    request({
      url: "/taShopKeeper",
      params: { shopId: id, ...params },
      method: "get"
    }).then(res => {
      const { records, ...page } = res.data.data;
      const newList = records || []
      setList(page.current === 1 ? newList : list.concat(newList))
      setPage({
        ...page,
        pageNum: page.current
      });
    });
  }

  const onDelete = keeperId => {
    Taro.showModal({
      title: "确定删除该老板账号吗",
      content: "确定后，该老板房源信息将一并删除",
      cancelColor: "#d2d2d2",
      confirmColor: "#274191",
      success: res => {
        if (res.confirm) {
          console.log("用户点击确定");
          request({ url: `/taShopKeeper/${keeperId}`, method: "delete" }).then(
            res => {
              setList(list.filter(x => x.keeperId != keeperId));
            }
          );
        } else if (res.cancel) {
          console.log("用户点击取消");
        }
      }
    });
  };

  const loadMore = () => {
    getShopKepperList({ pageNum: page.pageNum + 1 });
  };

  useEffect(() => {
    if (tabRef.current) {
      const h = `calc(100vh - 10px - ${tabRef.current.offsetHeight}px)`
      setListHeight(h)
    }
  }, [tabRef.current])

  const renderItem = (index, key) => (
    <View className="account-view" key={key}>
      {/* <Text className='account-view-title'>房源编号：<Text style={{fontSize:"1rem"}}>{item.keeperId}</Text></Text> */}
      <ContainerLayout className="account-view-card">
        <View className="top">
          <View>姓名：{list[index].name}</View>
          <View>电话：{list[index].phone}</View>
          {/* <View>微信号：{x.user.name}</View>
          <View>房源数：{x.user.name}</View> */}
        </View>
        <View className="bottom">
          <Text
            onClick={() => {
              Taro.navigateTo({
                url: `/pages/account/edit/index?keeperId=${list[index].keeperId}`
              });
            }}
          >
            编辑
          </Text>
          <Text onClick={() => onDelete(list[index].keeperId)}>删除</Text>
        </View>
      </ContainerLayout>
    </View>
  );

  return (
    <IsLogin>
      <View className="account">
        <Layout>
          <NoData
            nodata={!list.length}
            tips="暂无老板"
            style={{ minHeight: "200px" }}
          >
            <InifiniteList
              length={list.length}
              total={page.total}
              height={listHeight}
              itemRenderer={renderItem}
              loadMore={loadMore}
            />
          </NoData>
        </Layout>
        {/* onClick={(e)=>(e) */}
        <Tab
          ref={tabRef}
          value={["+新增民宿老板账号"]}
          color="#ffffff"
          onClick={() => {
            Taro.navigateTo({ url: `/pages/account/edit/index?id=${id}` });
          }}
        ></Tab>
      </View>
    </IsLogin>
  );
};

export default account;
