import React, { useEffect, useState } from "react";
import Taro, { useRouter } from "@tarojs/taro";
import { View, Input, Text, Image } from "@tarojs/components";
import Layout from "../../../layout/index";
import Tab from "../../../compents/tab/index";
import Container from "../../../compents/container/index";
import uploadicon from "../../../assets/uploadicon.png";
import "./index.scss";
import request, { uploadFiles } from "../../../util/request";
import getQueryValue from "../../../util/getQueryValue";
import IsLogin from "../../../layout/IsLogin";

const index = props => {
  const [shopInfo, setShopInfo] = useState({});
  const [name, setName] = useState("");
  const [imgUrl, setImgUrl] = useState("");
  const queryParams = getQueryValue() || {}
  
  const shopId = queryParams.id

  const editShopKeeper = () => {
    if (!name) {
      Taro.showToast({
        title: "请输入名称",
        icon: "none",
        duration: 2000
      });
      return;
    }
    if (!imgUrl) {
      Taro.showToast({
        title: "请上传图片",
        icon: "none",
        duration: 2000
      });
      return;
    }

    if (!shopId) {
      request({
        url: "/taShop",
        data: { name: name, logo: imgUrl },
        method: "post"
      }).then(res => {
        Taro.showModal({
          title: "新增成功",
          content: "点击确认按钮，返回上级菜单",
          showCancel: false,
          success: function(res) {
            if (res.confirm) {
              console.log("用户点击确定");
  
              Taro.navigateBack({
                delta: 1
              });
            } else if (res.cancel) {
              console.log("用户点击取消");
            }
          }
        });
      });
    } else {
      request({
        url: `/taShop/${shopId}`,
        data: { shopId, name: name, logo: imgUrl },
        method: "put"
      }).then(res => {
        Taro.showModal({
          title: "更新成功",
          content: "点击确认按钮，返回上级菜单",
          showCancel: false,
          success: function(res) {
            if (res.confirm) {
              console.log("用户点击确定");
  
              Taro.navigateBack({
                delta: 1
              });
            } else if (res.cancel) {
              console.log("用户点击取消");
            }
          }
        });
      });
    }
  };
  function handNameChange(e) {
    setName(e.detail.value);
  }

  const onUpImage = () => {
    Taro.chooseImage({
      sourceType: ["album"],
      success: res => {
        const tempFilePaths = res.tempFilePaths;
        uploadFiles(tempFilePaths).then(res => {
          setImgUrl(res[0]);
        });
      }
    });
  };

  useEffect(() => {
    if (shopId) {
      request({
        url: `/taShop/${shopId}`,
        method: "get"
      }).then(res => {
        console.log('--------->', res)
        const data = res.data.data
        setShopInfo(data)
        setName(data.name)
        setImgUrl(data.logo)
      });
    }
  }, [shopId])

  return (
    <IsLogin>
      <View className="addnewhouse">
        <Layout>
          <View className="inputstyle-view">
            <Text className="title">店铺名称</Text>
            <Container className="inputstyle-view-card ">
              <Input
                name="keeperId"
                value={name}
                placeholderClass="placeholderinput"
                onInput={handNameChange}
                placeholder=""
                className="input"
              />
            </Container>
          </View>

          <View className="inputstyle-view">
            <Text className="title">logo</Text>
            <Container
              className="inputstyle-view-card "
              style={{ padding: "0.6rem", width: "2rem", height: "2rem" }}
            >
              <Image
                className="guide-view-img"
                style={{ width: "100%", height: "100%" }}
                onClick={() => onUpImage()}
                src={imgUrl || uploadicon}
              ></Image>
            </Container>
          </View>
        </Layout>
        <Tab
          className="addhousetab"
          pageState="3"
          value={["取消", "确认添加"]}
          onClick={[
            e => {
              Taro.navigateBack({
                delta: 1
              });
            },
            () => editShopKeeper()
          ]}
        ></Tab>
      </View>
    </IsLogin>
  );
};

export default index;
